(function () {
    'use strict';

    queueListService.$inject = ["$resource", "amlConfig", "exceptionResourceHandler"];
    angular
        .module('aml.admin')
        .factory('queueListService', queueListService);


    function queueListService($resource, amlConfig, exceptionResourceHandler) {


        //the url here is: http://d10c667.na.sas.com:8780/SASComplianceSolutionsMid/rest so add the /queues
        var queueResource = $resource(amlConfig.baseUrl + '/queues',
            {},     //empty, we just send the queue object -- Spring serializes/de-serializes to java object of type Queue when requested
            {
                create: {
                    method: 'POST',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                get: {
                    method: 'GET',
                    interceptor: { responseError: exceptionResourceHandler.resourceErrorHandler }
                },
                update: {
                    method: 'PUT', interceptor: {responseError: exceptionResourceHandler.resourceErrorHandler}
                    //this is idempotent, resource change is independent of number of times requested
                }
            }
        );

        function createQueue(queue) {
            return queueResource.create( queue ).$promise;
        }

        function getQueues() {
            return queueResource.get({ }).$promise;
        }

        function updateQueue(queue) {       //used for updating a logically deleting a queue
            return queueResource.update( queue ).$promise;
        }


        var service = {

            getQueues: getQueues,
            createQueue: createQueue,
            updateQueue: updateQueue

        };


        return service;

    }
})();
